#!/bin/sh
# the next line restarts using wish\
exec wish "$0" "$@" 

if {![info exists vTcl(sourcing)]} {

    # Provoke name search
    catch {package require bogus-package-name}
    set packageNames [package names]

    package require BWidget
    switch $tcl_platform(platform) {
	windows {
	}
	default {
	    option add *ScrolledWindow.size 14
	}
    }
    
    package require Tk
    switch $tcl_platform(platform) {
	windows {
            option add *Button.padY 0
	}
	default {
            option add *Scrollbar.width 10
            option add *Scrollbar.highlightThickness 0
            option add *Scrollbar.elementBorderWidth 2
            option add *Scrollbar.borderWidth 2
	}
    }
    
}

#############################################################################
# Visual Tcl v1.60 Project
#


#################################
# VTCL LIBRARY PROCEDURES
#

if {![info exists vTcl(sourcing)]} {
#############################################################################
## Library Procedure:  Window

proc ::Window {args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    global vTcl
    foreach {cmd name newname} [lrange $args 0 2] {}
    set rest    [lrange $args 3 end]
    if {$name == "" || $cmd == ""} { return }
    if {$newname == ""} { set newname $name }
    if {$name == "."} { wm withdraw $name; return }
    set exists [winfo exists $newname]
    switch $cmd {
        show {
            if {$exists} {
                wm deiconify $newname
            } elseif {[info procs vTclWindow$name] != ""} {
                eval "vTclWindow$name $newname $rest"
            }
            if {[winfo exists $newname] && [wm state $newname] == "normal"} {
                vTcl:FireEvent $newname <<Show>>
            }
        }
        hide    {
            if {$exists} {
                wm withdraw $newname
                vTcl:FireEvent $newname <<Hide>>
                return}
        }
        iconify { if $exists {wm iconify $newname; return} }
        destroy { if $exists {destroy $newname; return} }
    }
}
#############################################################################
## Library Procedure:  vTcl:DefineAlias

proc ::vTcl:DefineAlias {target alias widgetProc top_or_alias cmdalias} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    global widget
    set widget($alias) $target
    set widget(rev,$target) $alias
    if {$cmdalias} {
        interp alias {} $alias {} $widgetProc $target
    }
    if {$top_or_alias != ""} {
        set widget($top_or_alias,$alias) $target
        if {$cmdalias} {
            interp alias {} $top_or_alias.$alias {} $widgetProc $target
        }
    }
}
#############################################################################
## Library Procedure:  vTcl:DoCmdOption

proc ::vTcl:DoCmdOption {target cmd} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    ## menus are considered toplevel windows
    set parent $target
    while {[winfo class $parent] == "Menu"} {
        set parent [winfo parent $parent]
    }

    regsub -all {\%widget} $cmd $target cmd
    regsub -all {\%top} $cmd [winfo toplevel $parent] cmd

    uplevel #0 [list eval $cmd]
}
#############################################################################
## Library Procedure:  vTcl:FireEvent

proc ::vTcl:FireEvent {target event {params {}}} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    ## The window may have disappeared
    if {![winfo exists $target]} return
    ## Process each binding tag, looking for the event
    foreach bindtag [bindtags $target] {
        set tag_events [bind $bindtag]
        set stop_processing 0
        foreach tag_event $tag_events {
            if {$tag_event == $event} {
                set bind_code [bind $bindtag $tag_event]
                foreach rep "\{%W $target\} $params" {
                    regsub -all [lindex $rep 0] $bind_code [lindex $rep 1] bind_code
                }
                set result [catch {uplevel #0 $bind_code} errortext]
                if {$result == 3} {
                    ## break exception, stop processing
                    set stop_processing 1
                } elseif {$result != 0} {
                    bgerror $errortext
                }
                break
            }
        }
        if {$stop_processing} {break}
    }
}
#############################################################################
## Library Procedure:  vTcl:Toplevel:WidgetProc

proc ::vTcl:Toplevel:WidgetProc {w args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    if {[llength $args] == 0} {
        ## If no arguments, returns the path the alias points to
        return $w
    }
    set command [lindex $args 0]
    set args [lrange $args 1 end]
    switch -- [string tolower $command] {
        "setvar" {
            foreach {varname value} $args {}
            if {$value == ""} {
                return [set ::${w}::${varname}]
            } else {
                return [set ::${w}::${varname} $value]
            }
        }
        "hide" - "show" {
            Window [string tolower $command] $w
        }
        "showmodal" {
            ## modal dialog ends when window is destroyed
            Window show $w; raise $w
            grab $w; tkwait window $w; grab release $w
        }
        "startmodal" {
            ## ends when endmodal called
            Window show $w; raise $w
            set ::${w}::_modal 1
            grab $w; tkwait variable ::${w}::_modal; grab release $w
        }
        "endmodal" {
            ## ends modal dialog started with startmodal, argument is var name
            set ::${w}::_modal 0
            Window hide $w
        }
        default {
            uplevel $w $command $args
        }
    }
}
#############################################################################
## Library Procedure:  vTcl:WidgetProc

proc ::vTcl:WidgetProc {w args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    if {[llength $args] == 0} {
        ## If no arguments, returns the path the alias points to
        return $w
    }

    set command [lindex $args 0]
    set args [lrange $args 1 end]
    uplevel $w $command $args
}
#############################################################################
## Library Procedure:  vTcl:toplevel

proc ::vTcl:toplevel {args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    uplevel #0 eval toplevel $args
    set target [lindex $args 0]
    namespace eval ::$target {set _modal 0}
}
}


if {[info exists vTcl(sourcing)]} {

proc vTcl:project:info {} {
    set base .top47
    namespace eval ::widgets::$base {
        set set,origin 1
        set set,size 1
        set runvisible 1
    }
    namespace eval ::widgets::$base.not48 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -disabledforeground 1 -foreground 1 -height 1 -width 1}
        namespace eval subOptions {
            array set save {-background 1 -leavecmd 1 -raisecmd 1 -text 1}
        }
    }
    set site_4_0 [$base.not48 getframe page1]
    namespace eval ::widgets::$site_4_0 {
        array set save {-background 1 -borderwidth 1}
    }
    set site_4_0 $site_4_0
    namespace eval ::widgets::$site_4_0.cpd51 {
        array set save {-background 1 -borderwidth 1 -text 1 -width 1}
    }
    set site_4_1 [$base.not48 getframe page5]
    namespace eval ::widgets::$site_4_1 {
        array set save {-background 1 -borderwidth 1}
    }
    set site_4_0 $site_4_1
    namespace eval ::widgets::$site_4_0.cpd55 {
        array set save {-background 1 -foreground 1 -text 1 -width 1}
    }
    set site_4_2 [$base.not48 getframe page2]
    namespace eval ::widgets::$site_4_2 {
        array set save {-background 1 -borderwidth 1 -highlightbackground 1}
    }
    set site_4_0 $site_4_2
    namespace eval ::widgets::$site_4_0.mes50 {
        array set save {-background 1 -text 1 -width 1}
    }
    set site_4_3 [$base.not48 getframe page3]
    namespace eval ::widgets::$site_4_3 {
        array set save {-background 1 -borderwidth 1}
    }
    set site_4_0 $site_4_3
    namespace eval ::widgets::$site_4_0.cpd52 {
        array set save {-background 1 -text 1 -width 1}
    }
    set site_4_4 [$base.not48 getframe page4]
    namespace eval ::widgets::$site_4_4 {
        array set save {-background 1 -borderwidth 1}
    }
    set site_4_0 $site_4_4
    namespace eval ::widgets::$site_4_0.cpd53 {
        array set save {-background 1 -text 1 -width 1}
    }
    set site_4_5 [$base.not48 getframe page6]
    namespace eval ::widgets::$site_4_5 {
        array set save {-background 1 -borderwidth 1}
    }
    set site_4_0 $site_4_5
    namespace eval ::widgets::$site_4_0.cpd47 {
        array set save {-background 1 -foreground 1 -text 1 -width 1}
    }
    set site_4_6 [$base.not48 getframe page7]
    namespace eval ::widgets::$site_4_6 {
        array set save {-background 1 -borderwidth 1}
    }
    set site_4_0 $site_4_6
    namespace eval ::widgets::$site_4_0.cpd48 {
        array set save {-background 1 -foreground 1 -text 1 -width 1}
    }
    set site_4_7 [$base.not48 getframe page8]
    namespace eval ::widgets::$site_4_7 {
        array set save {-background 1 -highlightcolor 1}
    }
    set site_4_0 $site_4_7
    namespace eval ::widgets::$site_4_0.cpd47 {
        array set save {-background 1 -foreground 1 -highlightthickness 1 -text 1 -width 1}
    }
    set site_4_8 [$base.not48 getframe page9]
    namespace eval ::widgets::$site_4_8 {
        array set save {-background 1 -borderwidth 1}
    }
    set site_4_0 $site_4_8
    namespace eval ::widgets::$site_4_0.cpd48 {
        array set save {-background 1 -foreground 1 -text 1 -width 1}
    }
    namespace eval ::widgets::$base.but49 {
        array set save {-command 1 -text 1}
    }
    set base .top49
    namespace eval ::widgets::$base {
        set set,origin 1
        set set,size 1
        set runvisible 1
    }
    namespace eval ::widgets_bindings {
        set tagslist _TopLevel
    }
    namespace eval ::vTcl::modules::main {
        set procs {
            init
            main
        }
        set compounds {
        }
        set projectType single
    }
}
}

#################################
# USER DEFINED PROCEDURES
#
#############################################################################
## Procedure:  main

proc ::main {argc argv} {}

#############################################################################
## Initialization Procedure:  init

proc ::init {argc argv} {}

init $argc $argv

#################################
# VTCL GENERATED GUI PROCEDURES
#

proc vTclWindow. {base} {
    if {$base == ""} {
        set base .
    }
    ###################
    # CREATING WIDGETS
    ###################
    wm focusmodel $top passive
    wm geometry $top 1x1+0+0; update
    wm maxsize $top 1265 994
    wm minsize $top 1 1
    wm overrideredirect $top 0
    wm resizable $top 1 1
    wm withdraw $top
    wm title $top "vtcl.tcl"
    bindtags $top "$top Vtcl.tcl all"
    vTcl:FireEvent $top <<Create>>
    wm protocol $top WM_DELETE_WINDOW "vTcl:FireEvent $top <<DeleteWindow>>"

    ###################
    # SETTING GEOMETRY
    ###################

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top47 {base} {
    if {$base == ""} {
        set base .top47
    }
    if {[winfo exists $base]} {
        wm deiconify $base; return
    }
    set top $base
    ###################
    # CREATING WIDGETS
    ###################
    vTcl:toplevel $top -class Toplevel \
        -background #ffffff 
    wm focusmodel $top passive
    wm geometry $top 537x265+574+532; update
    wm maxsize $top 1265 994
    wm minsize $top 1 1
    wm overrideredirect $top 0
    wm resizable $top 1 1
    wm deiconify $top
    wm title $top "Welcome to Puppy"
    vTcl:DefineAlias "$top" "Toplevel1" vTcl:Toplevel:WidgetProc "" 1
    bindtags $top "$top Toplevel all _TopLevel"
    vTcl:FireEvent $top <<Create>>
    wm protocol $top WM_DELETE_WINDOW "vTcl:FireEvent $top <<DeleteWindow>>"

    NoteBook $top.not48 \
        -activebackground #cccccc -activeforeground #666666 \
        -background #cccccc -disabledforeground #666666 -foreground #666666 \
        -height 229 -width 544 
    vTcl:DefineAlias "$top.not48" "NoteBook1" vTcl:WidgetProc "Toplevel1" 1
    $top.not48 insert end page1 \
        -background #ffff00 -leavecmd {} -raisecmd {} -text Welcome 
    $top.not48 insert end page5 \
        -background #ff0000 -leavecmd {} -raisecmd {} -text Advice 
    $top.not48 insert end page2 \
        -background #00ffff -leavecmd {} -raisecmd {} -text Screen 
    $top.not48 insert end page3 \
        -background #00ff00 -leavecmd {} -raisecmd {} -text Connecting 
    $top.not48 insert end page4 \
        -background #ff00ff -leavecmd {} -raisecmd {} -text DotPup 
    $top.not48 insert end page6 \
        -background #009999 -leavecmd {} -raisecmd {} -text Linux 
    $top.not48 insert end page7 \
        -background #ffffff -leavecmd {} -raisecmd {} -text BowWow 
    $top.not48 insert end page8 \
        -background #0000ff -leavecmd {} -raisecmd {} -text Tips 
    $top.not48 insert end page9 \
        -background {} -leavecmd {} -raisecmd {} -text Credits 
    set site_4_0 [$top.not48 getframe page1]
    message $site_4_0.cpd51 \
        -background #ffff00 -borderwidth 8 \
        -text {If you are a new Puppy user, new to Linux

           Welcome

              To more speed
              More control
              Easier use

  * Puppy runs in Ram 
  * Uses a recognizable "generic" interface
  * Puppy runs fast. Woosh!
  * Puppy is cute and fun} \
        -width 544 
    vTcl:DefineAlias "$site_4_0.cpd51" "Message5" vTcl:WidgetProc "Toplevel1" 1
    place $site_4_0.cpd51 \
        -in $site_4_0 -x -10 -y -10 -width 539 -height 205 -anchor nw \
        -bordermode inside 
    set site_4_1 [$top.not48 getframe page5]
    message $site_4_1.cpd55 \
        -background #ff0000 -foreground #ffffff \
        -text {Puppy comes with built in help 

        Start / Help

* Install - Pupgets and dotpups - extra programs 
* Forum link - click Forum dog
* Chat with IRC - instant messaging 
* News - Wiki link - wiki pages can be edited
* Web Page - puppylinux.com



} \
        -width 529 
    vTcl:DefineAlias "$site_4_1.cpd55" "Message8" vTcl:WidgetProc "Toplevel1" 1
    place $site_4_1.cpd55 \
        -in $site_4_1 -x -10 -y -10 -width 539 -height 205 -anchor nw \
        -bordermode inside 
    set site_4_2 [$top.not48 getframe page2]
    message $site_4_2.mes50 \
        -background #00ffff \
        -text {Change Screen Resolution

Changing the resolution is offered on first start

Your preferred resolution may just be on screen
 - click it and see . . .

    Later use the wizard from the start button 
    Start / Setup / Xvesa Video wizard

    eg options come up, press enter until the last entry    
    then choose and type 0x011A (or your preferred resolution) } \
        -width 534 
    vTcl:DefineAlias "$site_4_2.mes50" "Message4" vTcl:WidgetProc "Toplevel1" 1
    place $site_4_2.mes50 \
        -in $site_4_2 -x 0 -y 0 -width 534 -height 205 -anchor nw \
        -bordermode ignore 
    set site_4_3 [$top.not48 getframe page3]
    message $site_4_3.cpd52 \
        -background #00ff00 \
        -text {Internet Connection

Ethernet Broadband

	Start / Setup / Ethernet network wizard
		then in order:     
            Test
            Configure
            Auto-DHCP

Modem 
       Start / Network / Gkdial analog modem dialup or Xeznet} \
        -width 537 
    vTcl:DefineAlias "$site_4_3.cpd52" "Message6" vTcl:WidgetProc "Toplevel1" 1
    place $site_4_3.cpd52 \
        -in $site_4_3 -x -10 -y -10 -width 539 -height 205 -anchor nw \
        -bordermode inside 
    set site_4_4 [$top.not48 getframe page4]
    message $site_4_4.cpd53 \
        -background #ff00ff \
        -text {Puppy has two installers built in
       Pupget - these tend to be well tested
       Dotpup - these tend to be very up to date 

Use Dotpups to load latest programs

    * Click on Start / Startup / Dotpup Package Installer
 
} \
        -width 538 
    vTcl:DefineAlias "$site_4_4.cpd53" "Message7" vTcl:WidgetProc "Toplevel1" 1
    place $site_4_4.cpd53 \
        -in $site_4_4 -x -10 -y -10 -width 539 -height 205 -anchor nw \
        -bordermode inside 
    set site_4_5 [$top.not48 getframe page6]
    message $site_4_5.cpd47 \
        -background #009999 -foreground #ffffff \
        -text {/ = root directories descend from here
bin = Binary executable and links to executable programs
dev = Device. Access hardware devices on the computer
etc = Other stuff. Configuration files running in Linux
lib = Library. System file libraries used by Linux programs
lost+found = Initally empty. Files created by disk checking
mnt = Mount. HD, Floppy, CD and other devices become readable
proc = Process. System files for hardware/software statistics
root = Root. Home directory of admin/su account
sbin = System binary. System administration programs
tmp = Temporary files eg from downloads and installs
usr = User. Extensive user files and program store
var = Variable. Changing files eg. printer spool and log files} \
        -width 546 
    vTcl:DefineAlias "$site_4_5.cpd47" "Message11" vTcl:WidgetProc "Toplevel1" 1
    place $site_4_5.cpd47 \
        -in $site_4_5 -x -10 -y -10 -width 539 -height 205 -anchor nw \
        -bordermode inside 
    set site_4_6 [$top.not48 getframe page7]
    message $site_4_6.cpd48 \
        -background #ffffff -foreground #666666 \
        -text {Bow Wow is the unofficial geek talk of Puppy

    Pup = Puppy Newby or New User
    Puppy = User of Puppy linux
    Litter = Gathering of Puppy users such as on the forum
    ChubbyPuppy = Puppy with extras (OpenOffice)
    BareBones Pup = Cut down Puppy
    Puppian = Anything to do with Puppy
    Puplet = User created Puppy Linux eg PizzaPup
    Woof woof = approval   } \
        -width 539 
    vTcl:DefineAlias "$site_4_6.cpd48" "Message10" vTcl:WidgetProc "Toplevel1" 1
    place $site_4_6.cpd48 \
        -in $site_4_6 -x -10 -y -10 -width 539 -height 205 -anchor nw \
        -bordermode inside 
    set site_4_7 [$top.not48 getframe page8]
    message $site_4_7.cpd47 \
        -background #0000ff -foreground #ffffff -highlightthickness 2 \
        -text {to change the background of the icon text:
Rox 
    * Options
    * Pinboard
    * No background
    * Save (apply other effects to check but always SAVE)


Be Kind to Puppys} \
        -width 538 
    vTcl:DefineAlias "$site_4_7.cpd47" "Message9" vTcl:WidgetProc "Toplevel1" 1
    place $site_4_7.cpd47 \
        -in $site_4_7 -x -10 -y -10 -width 539 -height 205 -anchor nw \
        -bordermode inside 
    set site_4_8 [$top.not48 getframe page9]
    message $site_4_8.cpd48 \
        -background #cccccc -foreground #666666 \
        -text {Created by Ed Jason aka Lobster for Puppy Linux

http://peace.wikicities.com/wiki/Tmxxine_Linux
Ed.Jason@gmail.com

Special thanks:

Barry Kauler for creating Puppy
Ian for coding help and wiki text used here
GuestToo for constant advice, help, encouragement and Dotpups
Also: Flash, Bladehunter, John Murga, Babbs, Pizzasgood, 
Jesse, Papasmurf, JaDy, Xanatos and many new friends . . . 

. . . and "The Forum Puppys"} \
        -width 519 
    vTcl:DefineAlias "$site_4_8.cpd48" "Message12" vTcl:WidgetProc "Toplevel1" 1
    place $site_4_8.cpd48 \
        -in $site_4_8 -x -10 -y -10 -width 539 -height 205 -anchor nw \
        -bordermode inside 
    $top.not48 raise page1
    button $top.but49 \
        -command exit -text Exit 
    vTcl:DefineAlias "$top.but49" "Button1" vTcl:WidgetProc "Toplevel1" 1
    ###################
    # SETTING GEOMETRY
    ###################
    place $top.not48 \
        -in $top -x -5 -y 0 -width 539 -height 229 -anchor nw \
        -bordermode ignore 
    place $top.but49 \
        -in $top -x 465 -y 235 -anchor nw -bordermode ignore 

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top49 {base} {
    if {$base == ""} {
        set base .top49
    }
    if {[winfo exists $base]} {
        wm deiconify $base; return
    }
    set top $base
    ###################
    # CREATING WIDGETS
    ###################
    vTcl:toplevel $top -class Toplevel \
        -background #ffffff -highlightbackground #ffffff \
        -highlightcolor #ffffff 
    wm withdraw $top
    wm focusmodel $top passive
    wm geometry $top 553x412+235+514; update
    wm maxsize $top 1265 994
    wm minsize $top 1 1
    wm overrideredirect $top 0
    wm resizable $top 1 1
    wm title $top "New Toplevel 2"
    vTcl:DefineAlias "$top" "Toplevel2" vTcl:Toplevel:WidgetProc "" 1
    bindtags $top "$top Toplevel all _TopLevel"
    vTcl:FireEvent $top <<Create>>
    wm protocol $top WM_DELETE_WINDOW "vTcl:FireEvent $top <<DeleteWindow>>"

    ###################
    # SETTING GEOMETRY
    ###################

    vTcl:FireEvent $base <<Ready>>
}

#############################################################################
## Binding tag:  _TopLevel

bind "_TopLevel" <<Create>> {
    if {![info exists _topcount]} {set _topcount 0}; incr _topcount
}
bind "_TopLevel" <<DeleteWindow>> {
    if {[set ::%W::_modal]} {
                vTcl:Toplevel:WidgetProc %W endmodal
            } else {
                destroy %W; if {$_topcount == 0} {exit}
            }
}
bind "_TopLevel" <Destroy> {
    if {[winfo toplevel %W] == "%W"} {incr _topcount -1}
}

Window show .
Window show .top47
Window show .top49

main $argc $argv
